pub struct DoubleHasher { /* private fields */ }Expand description
Double hasher for bloom filter position generation.
Produces an infinite sequence of hash values derived from a single source hash using the double hashing technique.
Implementations
Sourceimpl DoubleHasher
impl DoubleHasher
Sourcepub fn new(h1: u64) -> Self
pub fn new(h1: u64) -> Self
Creates a DoubleHasher with two 64-bit hashes (h1, h2) from h1. Derives h2 by taking the upper 32 bits of h1 and multiplying it with H2_MULTIPLIER, a large number with mixed bits, to distribute the bits across h2.
Sourcepub fn with_value(value: &[u8], seed: u128) -> Self
pub fn with_value(value: &[u8], seed: u128) -> Self
Creates a DoubleHasher from a byte value we want to insert or check in the bloom filter (e.g., an object ID).
Entry point for bloom filter operations. Iterate through the DoubleHasher to produce the index of the block and the bit positions set in that block for a value and seed so we can
- set bit positions in a bloom filter for a value
- check if a value is in the bloom filter
Sourcepub fn next_hash(&mut self) -> u64
pub fn next_hash(&mut self) -> u64
Generate a new hash value from the current h1 and h2 with:
- modulo addition of two independent hashes with well distributed bits to ensure inputs diverge into uncorrelated bits.
- circular left shift by 5 (coprime to 64) to avoid evenly spaced distributions by mixing high and low bits after the addition.